@@ -29,9 +29,9 @@ from cubicweb.predicates import (
 )
 from cubicweb.uilib import exc_message
 from cubicweb.utils import json_dumps
-from cubicweb.web import RemoteCallFailed, DirectResponse
-from cubicweb.web.controller import Controller
-from cubicweb.web.views.urlrewrite import rgx_action, SchemaBasedRewriter
+from cubicweb_web import RemoteCallFailed, DirectResponse
+from cubicweb_web.controller import Controller
+from cubicweb_web.views.urlrewrite import rgx_action, SchemaBasedRewriter
 from cubicweb import Binary
 from cubicweb_rqlcontroller.rql_schema_holder import RqlIOSchemaHolder
 
